#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 attoparsec-iso8601
version:              1.1.1.0
visibility:           public
id:                   attoparsec-iso8601-1.1.1.0-DdbOZZw8TH16p9iKzXDbvM
key:                  attoparsec-iso8601-1.1.1.0-DdbOZZw8TH16p9iKzXDbvM
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Parsing of ISO 8601 dates, originally from aeson
description:          Parsing of ISO 8601 dates, originally from aeson.
category:             Parsing
abi:                  81e924ea86055bb8609659c0796e16ec
exposed:              True
exposed-modules:      Data.Attoparsec.Time Data.Attoparsec.Time.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/attoparsec-iso8601-1.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/attoparsec-iso8601-1.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/attoparsec-iso8601-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec-iso8601
hs-libraries:         HSattoparsec-iso8601-1.1.1.0-DdbOZZw8TH16p9iKzXDbvM
depends:
    attoparsec-0.14.4-3JRMoINo5azLplLZog31oy base-4.18.2.1
    integer-conversion-0.1.1-CjzILKkzm8lHo0agJgwEaN text-2.0.2
    time-1.12.2 time-compat-1.9.8-1Csf8VzcGXk7rCL1JLzbPV

haddock-interfaces:
    /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

